from django.db import models

class LinkThruManager(models.Manager):
    """ A Custom Manager for link thrus """

    def get_random_link(self, link_zone):
        """
        Returns a random linkthru that belongs to the specified zone
        
        """
        try:
            link = self.get_query_set().filter(zone__slug=link_zone, enabled=True).order_by('?')[0]
        except IndexError:
            return None;

        return link

    def enabled(self):
        return self.get_query_set().filter(enabled=True)



def get_source_ip(request):
    from_ip = request.META['REMOTE_ADDR']
    # forwarded proxy fix
    if (not from_ip or from_ip == '127.0.0.1') and request.META.has_key('HTTP_X_FORWARDED_FOR'):
        from_ip = request.META['HTTP_X_FORWARDED_FOR']

    try:
        return {'from_ip': from_ip, 'excluded_ip': request.excluded_ip }
    except:
        return {'from_ip': from_ip }
